package org.sample.utils;

import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.ResourceConfiguration;
import org.drools.builder.ResourceType;
import org.drools.io.Resource;

/**
 * Class representing a resource that can be added to KnowledgeBuilder.
 * It encapsules few classes - Resource, ResourceType and optional ResourceConfiguration.
 *
 * @author tschloss
 */
public class DroolsResource {

    public static final DroolsResource[] ARRAY = new DroolsResource[0];
    private final Resource resource;
    private final ResourceType type;
    private final ResourceConfiguration configuration;

    /**
     * Constructs a new DroolsResource with no ResourceConfiguration
     *
     * @param resource - resource
     * @param type - type of resource
     * @throws NullPointerException - when resource or type is null
     */
    public DroolsResource(Resource resource, ResourceType type) {
        this(resource, type, null);
    }

    /**
     * Constructor
     *
     * @param resource - resource
     * @param type - type
     * @param configuration - configuration for KnowledgeBuilder
     * @throws NullPointerException - when resource or type is null
     */
    public DroolsResource(Resource resource, ResourceType type, ResourceConfiguration configuration) {
        if (resource == null) {
            throw new NullPointerException("Resource can't be null");
        }
        if (type == null) {
            throw new NullPointerException("Type can't be null");
        }
        this.resource = resource;
        this.type = type;
        this.configuration = configuration;
    }

    public Resource getResource() {
        return resource;
    }

    public ResourceType getType() {
        return type;
    }

    public ResourceConfiguration getConfiguration() {
        return configuration;
    }

    /**
     * Adds this Resource to suplied KnowledgeBuilder
     *
     * @param kbuilder - instance of KnowledgeBuilder to insert this resource to
     */
    public void addToKnowledgeBuilder(KnowledgeBuilder kbuilder) {
        if (configuration != null) {
            kbuilder.add(resource, type, configuration);
        } else {
            kbuilder.add(resource, type);
        }
    }

}
