package org.sample.utils;

import javax.persistence.Persistence;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.persistence.jpa.JPAKnowledgeService;
import org.drools.runtime.Environment;
import org.drools.runtime.EnvironmentName;
import org.drools.runtime.KnowledgeSessionConfiguration;
import org.drools.runtime.StatefulKnowledgeSession;
import org.drools.runtime.process.ProcessInstance;

public class Utils {
    public static KnowledgeBuilder createKnowledgeBuilder(DroolsResource... resources) {
        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();

        for (DroolsResource res : resources) {
            res.addToKnowledgeBuilder(kbuilder);
        }

        if (kbuilder.hasErrors()) {
            throw new RuntimeException(kbuilder.getErrors().toString());
        }

        return kbuilder;
    }

    public static StatefulKnowledgeSession createPersistedSession(KnowledgeBase kbase) {
        System.setProperty("hibernate.transaction.manager_lookup_class", "org.sample.utils.LocalTrasactionManagerLookup");

        Environment env = KnowledgeBaseFactory.newEnvironment();
        env.set(EnvironmentName.ENTITY_MANAGER_FACTORY, Persistence.createEntityManagerFactory("org.drools.persistence.jpa"));
        env.set(EnvironmentName.TRANSACTION, com.arjuna.ats.jta.UserTransaction.userTransaction());

        KnowledgeSessionConfiguration ksconf= KnowledgeBaseFactory.newKnowledgeSessionConfiguration();

        return JPAKnowledgeService.newStatefulKnowledgeSession(kbase, ksconf, env);
    }

    public static DroolsResource createResource(String name, Class<?> clazz, ResourceType type) {
        return new DroolsResource(ResourceFactory.newClassPathResource(name, clazz), type);
    }

    public static String convertState(int state) {
        switch (state) {
        case ProcessInstance.STATE_ABORTED:
            return "aborted";
        case ProcessInstance.STATE_ACTIVE:
            return "active";
        case ProcessInstance.STATE_COMPLETED:
            return "completed";
        case ProcessInstance.STATE_PENDING:
            return "pending";
        case ProcessInstance.STATE_SUSPENDED:
            return "suspended";
        default:
            return "unknowns";
        }
    }
}
